@@ -2,10 +2,11 @@ use warnings;
 use strict;
 package Mojolicious::Plugin::Mongodb;
 {
-  $Mojolicious::Plugin::Mongodb::VERSION = '1.11';
+  $Mojolicious::Plugin::Mongodb::VERSION = '1.12';
 }
 use Mojo::Base 'Mojolicious::Plugin';
 use MongoDB;
+use MongoDB::Collection;
 
 sub register {
     my $self = shift;
@@ -30,6 +31,7 @@ sub register {
     $app->helper('coll' => sub { return shift->app->_mongodb->coll(@_) });
 
     if(defined($conf->{patch_mongodb}) && $conf->{patch_mongodb} == 1) {
+        warn __PACKAGE__, ': patching MongoDB driver', "\n";
         use Moose::Util qw/find_meta/;
         if(my $meta = find_meta('MongoDB::Collection')) {
             $meta->make_mutable;
@@ -41,9 +43,8 @@ sub register {
                 $opts->{'ns'} = $self->name,
                 $opts->{'$reduce'} = delete($opts->{'reduce'}) if($opts->{'reduce'});
                 $opts->{'$keyf'} = delete($opts->{'keyf'}) if($opts->{'keyf'});
-                $opts->{'$finalize'} = delete($opts->{'finalize'}) if($opts->{'finalize'});
 
-                return $self->find_one({ group => $opts });
+                return $self->_database->run_command({ group => $opts });
             }, name => 'group', package_name => 'MongoDB::Collection'));
 
             $meta->add_method('find_and_modify' => Moose::Meta::Method->wrap(sub {
@@ -69,6 +70,8 @@ sub register {
             }, name => 'map_reduce', package_name => 'MongoDB::Collection'));
 
             $meta->make_immutable;
+        } else {
+            warn __PACKAGE__, ': could not find MongoDB::Collection meta', "\n";
         }
     } else {
         for my $helpername(qw/find_and_modify map_reduce group/) {
@@ -79,7 +82,7 @@ sub register {
 
 package Mojolicious::Plugin::Mongodb::Connection;
 {
-  $Mojolicious::Plugin::Mongodb::Connection::VERSION = '1.11';
+  $Mojolicious::Plugin::Mongodb::Connection::VERSION = '1.12';
 }
 use Mojo::Base -base;
 use Tie::IxHash;
@@ -152,7 +155,6 @@ sub group {
     $opts->{'ns'} = $self->name,
     $opts->{'$reduce'} = delete($opts->{'reduce'}) if($opts->{'reduce'});
     $opts->{'$keyf'} = delete($opts->{'keyf'}) if($opts->{'keyf'});
-    $opts->{'$finalize'} = delete($opts->{'finalize'}) if($opts->{'finalize'});
 
     return $self->find_one({ group => $opts });
 }
@@ -165,7 +167,7 @@ Mojolicious::Plugin::Mongodb - Use MongoDB in Mojolicious
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
